@@ -27,17 +27,26 @@ def is_termination(tree_or_token):
         return False
     return tree_or_token.type == 'TERMINATION'
 
-def get_vars_and_funcs_in_expr(expr):
+def get_constituents_of_expr(expr):
     """
     Returns a list of the variables used and functions called in the input
     expression. Two lists are returned. For variables the list is of
     sca2d.scadclasses.Variable objects but for the function calls they are
     lark.tree.Tree as they will require further processing in the calling scope.
     """
-    var_tokens = get_all_matching_tokens(expr , 'VARIABLE')
-    func_trees = get_all_matching_subtrees(expr , 'function_call')
+    excluded_trees = ['let_expr','echo_func', 'list_comp_expr', 'assert_func_expr']
+    if expr.data == 'function_call':
+        return [], [expr], []
+    if expr.data in ['let_expr', 'list_comp_expr', 'assert_func_expr']:
+        return [], [], [expr]
+    var_tokens = get_all_matching_tokens(expr, 'VARIABLE', exclude_trees=excluded_trees)
+    func_trees = get_all_matching_subtrees(expr , 'function_call', exclude_trees=excluded_trees)
+    lc_trees = get_all_matching_subtrees(expr , 'list_comp_expr', include_nested=False, exclude_trees=excluded_trees)
+    let_expr_trees = get_all_matching_subtrees(expr , 'let_expr', include_nested=False, exclude_trees=excluded_trees)
+    assert_exprs = get_all_matching_subtrees(expr , 'assert_func_expr', include_nested=False, exclude_trees=excluded_trees)
+    complex_expressions = lc_trees + let_expr_trees + assert_exprs
     variables = [Variable(token) for token in var_tokens]
-    return variables, func_trees
+    return variables, func_trees, complex_expressions
 
 def parse_assignment(assign_tree):
     """
@@ -46,32 +55,48 @@ def parse_assignment(assign_tree):
     """
     assigned_var = Variable(assign_tree.children[0])
     expr = assign_tree.children[1]
-    used_vars, used_functions = get_vars_and_funcs_in_expr(expr)
-    return assigned_var, used_vars, used_functions
+    used_vars, used_functions, complex_expressions = get_constituents_of_expr(expr)
+    return assigned_var, used_vars, used_functions, complex_expressions
 
-def get_all_matching_subtrees(tree, tree_name):
+def get_all_matching_subtrees(tree, tree_name, include_nested=True, exclude_trees=None):
     """
     Returns a list of all matching subtrees in the order they appear in the
     code. Trees match if Tree.data (i.e. the rule name in the .lark definion)
-    matches the input "tree_name".
+    matches the input "tree_name". If include nested then nested trees of the
+    same type will be found.
     """
+    if exclude_trees is not None:
+        if tree.data in exclude_trees:
+            return []
+
     subtrees = []
     for child in tree.children:
         if isinstance(child, Tree):
             if child.data == tree_name:
                 subtrees.append(child)
-            subtrees += get_all_matching_subtrees(child, tree_name)
+                if not include_nested:
+                    # Don't try to match subtrees if include_nested is false
+                    continue
+            subtrees += get_all_matching_subtrees(child,
+                                                  tree_name,
+                                                  include_nested=include_nested,
+                                                  exclude_trees=exclude_trees)
     return subtrees
 
-def get_all_matching_tokens(tree, token):
+def get_all_matching_tokens(tree, token, exclude_trees=None):
     """
     Returns a list of all matching tokens in the order they appear in the
-    code. Tokens match if Token.Type matches the input.
+    code. Tokens match if Token. Type matches the input.
+    Any tokens inside excluded tree types are not returned.
     """
+    if exclude_trees is not None:
+        if tree.data in exclude_trees:
+            return []
+
     tokens = []
     for child in tree.children:
         if isinstance(child, Tree):
-            tokens += get_all_matching_tokens(child, token)
+            tokens += get_all_matching_tokens(child, token, exclude_trees=exclude_trees)
         else:
             if child.type == token:
                 tokens.append(child)
